<?php

declare(strict_types=1);

namespace Drupal\wse\Diff\Form;

use Drupal\diff\Form\RevisionOverviewForm;
use Drupal\node\NodeInterface;
use Drupal\workspaces\WorkspaceManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a form for revision overview page.
 */
class WseRevisionOverviewForm extends RevisionOverviewForm {

  /**
   * The workspace manager.
   */
  protected WorkspaceManagerInterface $workspaceManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    $instance = parent::create($container);
    $instance->workspaceManager = $container->get('workspaces.manager');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  protected function getRevisionIds(NodeInterface $node): array {
    $query = $this->entityTypeManager->getStorage('node')->getQuery()
      ->condition($node->getEntityType()->getKey('id'), $node->id())
      ->pager($this->config->get('general_settings.revision_pager_limit'))
      ->allRevisions()
      ->sort($node->getEntityType()->getKey('revision'), 'DESC')
      // Access to the content has already been verified. Disable query-level
      // access checking so that revisions for unpublished content still
      // appear.
      ->accessCheck(FALSE);

    // When a workspace is active, filter the revisions to those created in that
    // workspace.
    if ($this->workspaceManager->hasActiveWorkspace()) {
      $active_workspace_id = $this->workspaceManager->getActiveWorkspace()->id();
      $query->condition($node->getEntityType()->getRevisionMetadataKey('workspace'), $active_workspace_id);
    }
    else {
      // Otherwise show only revisions that were not created in a workspace.
      $query->notExists($node->getEntityType()->getRevisionMetadataKey('workspace'));
    }

    return \array_keys($query->execute());
  }

}
